==> schema_learn-0.0.6.tar.gz: schema_learn-0.0.6/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os.path
import sys
from datetime import datetime

import matplotlib
matplotlib.use('agg')

#sys.path[:0] = [os.path.dirname(os.path.abspath(__file__)) + "/../../schema/"]
#import schema_qp

sys.path[:0] = [os.path.dirname(os.path.abspath(__file__)) + "/../../"]
import schema


# -- Project information -----------------------------------------------------

project = 'Schema'
copyright = '2020, Rohit Singh, Ashwin Narayan, Brian Hie'
author = 'Rohit Singh, Ashwin Narayan, Brian Hie'

# The full version, including alpha/beta/rc tags
release = '0.0.5'

master_doc = 'index'

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [ 'sphinx.ext.todo', 'sphinx.ext.viewcode', 'sphinx.ext.autodoc']


# Add any paths that contain templates here, relative to this directory.
templates_path = ['../_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

html_theme_options = {
    'logo_only':  True,
}


# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['../_static']
html_logo = '../_static/Schema-webpage-logo-2-blue.png'

==> schema_learn-0.0.7.tar.gz: schema_learn-0.0.7/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os.path
import sys
from datetime import datetime

import matplotlib
matplotlib.use('agg')

#sys.path[:0] = [os.path.dirname(os.path.abspath(__file__)) + "/../../schema/"]
#import schema_qp

sys.path[:0] = [os.path.dirname(os.path.abspath(__file__)) + "/../../"]
import schema


# -- Project information -----------------------------------------------------

project = 'Schema'
copyright = '2020, Rohit Singh, Ashwin Narayan, Brian Hie'
author = 'Rohit Singh, Ashwin Narayan, Brian Hie'

# The full version, including alpha/beta/rc tags
release = '0.0.5'

master_doc = 'index'

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [ 'sphinx.ext.todo', 'sphinx.ext.viewcode', 'sphinx.ext.autodoc']


# Add any paths that contain templates here, relative to this directory.
templates_path = ['../_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

html_theme_options = {
    'logo_only':  True,
}


# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['../_static']
html_logo = '../_static/Schema-webpage-logo-2-blue.png'

autoclass_content = 'both'


# def skip(app, what, name, obj, would_skip, options):
#     if name == "__init__":
#         return False
#     return would_skip

# def setup(app):
#     app.connect("autodoc-skip-member", skip)
